# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [PEP 440](https://www.python.org/dev/peps/pep-0440/)
and uses [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.2]
### Changed
- Update `ruff` configuration to our latest standards.

## [0.1.1]
### Added
* `fetch_for_scene` docstring to the usage section of the README.

## [0.1.0]
### Added
* `fetch_for_scene` function to download the best available orbit information for a scene.

